==> qcad-3.15.5.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl_PL">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation type="unfinished">Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation type="unfinished">Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Przesuń / kopiuj</translatorcomment>
        <translation type="unfinished">&amp;Przesuń / kopiuj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Przenoszenie lub kopiowanie jednostek raz lub kilka razy</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przemieszczania</translatorcomment>
        <translation type="unfinished">Opcje przemieszczania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation type="unfinished">Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation type="unfinished">&amp;Usuń oryginał</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation type="unfinished">&amp;Zachowaj oryginał</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation type="unfinished">Kopie &amp;wielokrotne</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation type="unfinished">Użyj bieżącej warstwy i atrybuty</translation>
    </message>
</context>
</TS>

==> qcad-3.21.2.3.tgz: lib/qcad/scripts/Modify/Translate/ts/Translate_pl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="pl">
<context>
    <name>Translate</name>
    <message>
        <location filename="../Translate.js" line="+44"/>
        <source>Modify</source>
        <translation>Modyfikowanie</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Move/Copy</source>
        <translation>Przenieś / skopiuj</translation>
    </message>
    <message>
        <location line="+27"/>
        <source>Reference point</source>
        <translatorcomment>--google--
Wskaż punkt odniesienia
Kopiuje obiekty do schowka z punktem odniesienia
Wycina obiekty z punktem odniesienia</translatorcomment>
        <translation>Punkt odniesienia</translation>
    </message>
    <message>
        <location line="+8"/>
        <source>Target point</source>
        <translatorcomment>--google--
Wskaż punkt docelowy</translatorcomment>
        <translation>Punkt docelowy</translation>
    </message>
    <message>
        <location filename="../TranslateInit.js" line="+2"/>
        <source>&amp;Move / Copy</source>
        <translatorcomment>--exact match--
--file: qcadactions_pl.ts--
&amp;Przesuń / kopiuj</translatorcomment>
        <translation>&amp;Przenieś / skopiuj</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Move or copy entities once or multiple times</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Przenosi lub kopiuje obiekty raz lub wiele razy</translation>
    </message>
    <message>
        <location filename="../PreferencesPage.ui" line="+17"/>
        <source>Use dialog for tool options</source>
        <translation>Wprowadzanie opcji w oknie dialogowym</translation>
    </message>
    <message>
        <location filename="../Translate.ui" line="+17"/>
        <source>Copy</source>
        <translation>Skopiowanie</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies:</source>
        <translation>Liczba kopii:</translation>
    </message>
    <message>
        <location line="+30"/>
        <source>Use current layer and &amp;attributes</source>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
<context>
    <name>TranslateOptions</name>
    <message>
        <location filename="../TranslateDialog.ui" line="+14"/>
        <source>Move / Copy Options</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Opcje przemieszczania</translatorcomment>
        <translation>Opcje przenoszenia / kopiowania</translation>
    </message>
    <message>
        <location line="+14"/>
        <source>Number of Copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Liczba kopii
Wprowadź liczbę kopii</translatorcomment>
        <translation>Liczba kopii</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>&amp;Delete original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Usuń oryginał</translatorcomment>
        <translation>&amp;Usunięcie oryginału</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>&amp;Keep original</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
&amp;Zachowaj oryginał</translatorcomment>
        <translation>&amp;Zachowanie oryginału</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>&amp;Multiple copies</source>
        <translatorcomment>--exact match--
--file: qcadguiqt_pl.ts--
Kopie &amp;wielokrotne
Kopie &amp;wielokrotne:</translatorcomment>
        <translation>&amp;Wielokrotne skopiowanie</translation>
    </message>
    <message>
        <location line="+86"/>
        <source>Use current layer and &amp;attributes</source>
        <translatorcomment>--google--</translatorcomment>
        <translation>Użycie aktualnej warstwy i &amp;atrybutów</translation>
    </message>
</context>
</TS>
